@@ -176,7 +176,7 @@ static int _find_x509_cert(const GNUTLS_CERTIFICATE_CREDENTIALS cred,
 	do {
 
 		DECR_LENGTH_RET(data_size, 2, 0);
-		size = READuint16(data);
+		size = _gnutls_read_uint16(data);
 		DECR_LENGTH_RET(data_size, size, 0);
 		data += 2;
 
@@ -330,7 +330,6 @@ static int _gnutls_find_acceptable_client_cert(GNUTLS_STATE state,
 	if (indx == -1 && state->gnutls_internals.client_cert_callback != NULL && cred->ncerts > 0) {	/* use a callback to get certificate */
 		gnutls_datum *my_certs = NULL;
 		gnutls_datum *issuers_dn = NULL;
-		int count;
 		int issuers_dn_len = 0;
 		opaque* dataptr = data;
 		int dataptr_size = data_size;
@@ -340,21 +339,19 @@ static int _gnutls_find_acceptable_client_cert(GNUTLS_STATE state,
 		 * using realloc().
 		 */
 		do {
-			dataptr_size -= 2;
-			if (dataptr_size <= 0)
-				goto clear;
-			size = READuint16(data);
+			/* This works like DECR_LEN() */
+			DECR_LENGTH_COM( dataptr_size, 2, goto clear);
+			size = _gnutls_read_uint16(data);
 
-			dataptr_size -= size;
-			if (dataptr_size < 0)
-				goto clear;
+			DECR_LENGTH_COM( dataptr_size, size, goto clear);
 
 			dataptr += 2;
 
-			issuers_dn_len++;
-
-			dataptr += size;
-
+			if (size > 0) {
+				issuers_dn_len++;
+				dataptr += size;
+			}
+			
 			if (dataptr_size == 0)
 				break;
 
@@ -384,12 +381,12 @@ static int _gnutls_find_acceptable_client_cert(GNUTLS_STATE state,
 				 */
 				data_size -= 2;
 
-				size = READuint16(data);
+				size = _gnutls_read_uint16(data);
 
 				data += 2;
 
-				issuers_dn[count].data = data;
-				issuers_dn[count].size = size;
+				issuers_dn[i].data = data;
+				issuers_dn[i].size = size;
 
 				data += size;
 
@@ -497,10 +494,10 @@ int _gnutls_gen_x509_certificate(GNUTLS_STATE state, opaque ** data)
 		gnutls_assert();
 		return GNUTLS_E_MEMORY_ERROR;
 	}
-	WRITEuint24(ret - 3, pdata);
+	_gnutls_write_uint24(ret - 3, pdata);
 	pdata += 3;
 	for (i = 0; i < apr_cert_list_length; i++) {
-		WRITEdatum24(pdata, apr_cert_list[i].raw);
+		_gnutls_write_datum24(pdata, apr_cert_list[i].raw);
 		pdata += (3 + apr_cert_list[i].raw.size);
 	}
 
@@ -540,17 +537,17 @@ int _gnutls_gen_openpgp_certificate(GNUTLS_STATE state,
 		return GNUTLS_E_MEMORY_ERROR;
 	}
 
-	WRITEuint24(ret - 3, pdata);
+	_gnutls_write_uint24(ret - 3, pdata);
 	pdata += 3;
 
 	*pdata = PGP_KEY;	/* whole key */
 	pdata++;
 
 	if (apr_cert_list_length > 0) {
-		WRITEdatum24(pdata, apr_cert_list[0].raw);
+		_gnutls_write_datum24(pdata, apr_cert_list[0].raw);
 		pdata += (3 + apr_cert_list[0].raw.size);
 	} else			/* empty - no certificate */
-		WRITEuint24(0, pdata);
+		_gnutls_write_uint24(0, pdata);
 
 	return ret;
 }
@@ -594,7 +591,7 @@ int _gnutls_gen_openpgp_certificate_fpr(GNUTLS_STATE state,
 		return GNUTLS_E_MEMORY_ERROR;
 	}
 
-	WRITEuint24(packet_size - 3, pdata);
+	_gnutls_write_uint24(packet_size - 3, pdata);
 	pdata += 3;
 
 	*pdata = PGP_KEY_FINGERPRINT;	/* key fingerprint */
@@ -698,7 +695,7 @@ int _gnutls_proc_x509_server_certificate(GNUTLS_STATE state, opaque * data,
 	}
 
 	DECR_LEN(dsize, 3);
-	size = READuint24(p);
+	size = _gnutls_read_uint24(p);
 	p += 3;
 
 	if (size == 0) {
@@ -710,7 +707,7 @@ int _gnutls_proc_x509_server_certificate(GNUTLS_STATE state, opaque * data,
 	i = dsize;
 	while(i > 0) {
 		DECR_LEN(dsize, 3);
-		len = READuint24(p);
+		len = _gnutls_read_uint24(p);
 		p += 3;
 		DECR_LEN(dsize, len);
 		peer_certificate_list_size++;
@@ -746,7 +743,7 @@ int _gnutls_proc_x509_server_certificate(GNUTLS_STATE state, opaque * data,
 	 */
 
 	for (j=0;j<peer_certificate_list_size;j++) {
-		len = READuint24(p);
+		len = _gnutls_read_uint24(p);
 		p += 3;
 
 		tmp.size = len;
@@ -830,7 +827,7 @@ int _gnutls_proc_openpgp_server_certificate(GNUTLS_STATE state,
 	}
 
 	DECR_LEN(dsize, 3);
-	size = READuint24(p);
+	size = _gnutls_read_uint24(p);
 	p += 3;
 
 	if (size == 0) {
@@ -875,7 +872,7 @@ int _gnutls_proc_openpgp_server_certificate(GNUTLS_STATE state,
 
 		/* Read the actual certificate */
 		DECR_LEN(dsize, 3);
-		len = READuint24(p);
+		len = _gnutls_read_uint24(p);
 		p += 3;
 
 		if (size == 0) {
@@ -1050,7 +1047,7 @@ int _gnutls_proc_cert_cert_req(GNUTLS_STATE state, opaque * data,
 
 	if (state->security_parameters.cert_type == GNUTLS_CRT_X509) {
 		DECR_LEN(dsize, 2);
-		size = READuint16(p);
+		size = _gnutls_read_uint16(p);
 		p += 2;
 	} else {
 		p = NULL;
@@ -1118,7 +1115,7 @@ int _gnutls_gen_cert_client_cert_vrfy(GNUTLS_STATE state, opaque ** data)
 		return GNUTLS_E_MEMORY_ERROR;
 	}
 	size = signature.size;
-	WRITEuint16(size, *data);
+	_gnutls_write_uint16(size, *data);
 
 	memcpy(&(*data)[2], signature.data, size);
 
@@ -1144,7 +1141,7 @@ int _gnutls_proc_cert_client_cert_vrfy(GNUTLS_STATE state, opaque * data,
 	}
 
 	DECR_LEN(dsize, 2);
-	size = READuint16(pdata);
+	size = _gnutls_read_uint16(pdata);
 	pdata += 2;
 
 	DECR_LEN(dsize, size);
@@ -1234,7 +1231,7 @@ int _gnutls_gen_cert_server_cert_req(GNUTLS_STATE state, opaque ** data)
 	pdata += CERTTYPE_SIZE;
 
 	if (state->security_parameters.cert_type == GNUTLS_CRT_X509) {
-		WRITEdatum16(pdata, cred->x509_rdn_sequence);
+		_gnutls_write_datum16(pdata, cred->x509_rdn_sequence);
 		pdata += cred->x509_rdn_sequence.size + 2;
 	}
 
