@@ -26,7 +26,7 @@
 extern "C" {
 #endif
 
-#define LIBGNUTLS_VERSION "0.4.2"
+#define LIBGNUTLS_VERSION "0.4.3"
 
 #include <sys/types.h>
 #include <time.h>
@@ -244,6 +244,14 @@ int gnutls_certificate_set_x509_key_mem(GNUTLS_CERTIFICATE_CREDENTIALS res,
 int gnutls_global_init(void);
 void gnutls_global_deinit(void);
 
+void gnutls_global_set_mem_func( 
+	void *(*gnutls_alloc_func)(size_t), void* (*gnutls_secure_alloc_func)(size_t),
+	int (*gnutls_is_secure_func)(const void*), void *(*gnutls_realloc_func)(void *, size_t),
+	void (*gnutls_free_func)(void*));
+
+typedef void (*GNUTLS_LOG_FUNC)( const char*);
+void gnutls_global_set_log_func( GNUTLS_LOG_FUNC log_func);
+
 int gnutls_dh_params_set( GNUTLS_DH_PARAMS, gnutls_datum prime, gnutls_datum generator, int bits);
 int gnutls_dh_params_init( GNUTLS_DH_PARAMS*);
 void gnutls_dh_params_deinit( GNUTLS_DH_PARAMS);
@@ -256,7 +264,6 @@ GNUTLS_TRANSPORT_PTR gnutls_transport_get_ptr(GNUTLS_STATE state);
 
 void gnutls_transport_set_lowat( GNUTLS_STATE state, int num);
 
-typedef void (*GNUTLS_LOG_FUNC)( const char*);
 
 void gnutls_transport_set_push_func( GNUTLS_STATE, GNUTLS_PUSH_FUNC push_func);
 void gnutls_transport_set_pull_func( GNUTLS_STATE, GNUTLS_PULL_FUNC pull_func);
@@ -274,7 +281,6 @@ size_t gnutls_record_check_pending(GNUTLS_STATE state);
 void gnutls_openpgp_send_key(GNUTLS_STATE state, GNUTLS_OpenPGPKeyStatus status);
 
 int gnutls_x509_fingerprint(GNUTLS_DigestAlgorithm algo, const gnutls_datum* data, char* result, size_t* result_size);
-int gnutls_openpgp_fingerprint( const gnutls_datum* data, char* result, size_t* result_size);
 #ifndef GNUTLS_UI_H
 # define GNUTLS_UI_H
 
