@@ -159,6 +159,7 @@ int _gnutls_record_buffer_get(ContentType type, GNUTLS_STATE state, char *data,
 		memmove(state->gnutls_internals.application_data_buffer.data,
 			&state->gnutls_internals.application_data_buffer.data[length],
 			state->gnutls_internals.application_data_buffer.size);
+
 		/* this does not fail */
 		state->gnutls_internals.application_data_buffer.data =
 		    gnutls_realloc_fast(state->gnutls_internals.application_data_buffer.data,
@@ -327,7 +328,7 @@ ssize_t _gnutls_io_read_buffered( GNUTLS_STATE state, opaque **iptr, size_t size
 	int min, buf_pos;
 	char *buf;
 	int recvlowat = RCVLOWAT;
-	int recvdata;
+	int recvdata, alloc_size;
 
 	*iptr = state->gnutls_internals.record_recv_buffer.data;
 
@@ -366,8 +367,10 @@ ssize_t _gnutls_io_read_buffered( GNUTLS_STATE state, opaque **iptr, size_t size
 	
 	/* Allocate the data required to store the new packet.
 	 */
+	 
+	alloc_size = recvdata+state->gnutls_internals.record_recv_buffer.size;
 	state->gnutls_internals.record_recv_buffer.data = gnutls_realloc_fast(
-		state->gnutls_internals.record_recv_buffer.data, recvdata+state->gnutls_internals.record_recv_buffer.size);
+		state->gnutls_internals.record_recv_buffer.data, alloc_size);
 	if ( state->gnutls_internals.record_recv_buffer.data==NULL) {
 		gnutls_assert();
 		return GNUTLS_E_MEMORY_ERROR;
