@@ -3,19 +3,20 @@
  *
  * This file is part of GNUTLS.
  *
- * GNUTLS is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ *  The GNUTLS library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Lesser General Public   
+ *  License as published by the Free Software Foundation; either 
+ *  version 2.1 of the License, or (at your option) any later version.
  *
- * GNUTLS is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of 
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Lesser General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this library; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
  */
 
 #include <gnutls_int.h>
@@ -25,7 +26,7 @@
 #include <x509_asn1.h>
 #include <x509_der.h>
 #include <gnutls_datum.h>
-#include <gnutls_gcry.h>
+#include <gnutls_mpi.h>
 #include <gnutls_global.h>
 #include <x509_verify.h>
 #include <gnutls_privkey.h>
@@ -36,7 +37,7 @@
 #include <gnutls_state.h>
 #include <gnutls_auth_int.h>
 #include <gnutls_x509.h>
-#include <gnutls_openpgp.h>
+#include <gnutls_extra.h>
 
 /* KX mappings to PK algorithms */
 typedef struct {
@@ -299,6 +300,13 @@ void gnutls_certificate_server_set_select_func(GNUTLS_STATE state,
 	state->gnutls_internals.server_cert_callback = func;
 }
 
+/* These are set by the gnutls_extra library's initialization function.
+ */
+
+OPENPGP_KEY_CREATION_TIME_FUNC _E_gnutls_openpgp_extract_key_creation_time = NULL;
+OPENPGP_KEY_EXPIRATION_TIME_FUNC _E_gnutls_openpgp_extract_key_expiration_time = NULL;
+OPENPGP_VERIFY_KEY_FUNC _E_gnutls_openpgp_verify_key = NULL;
+
 /*-
   * _gnutls_openpgp_cert_verify_peers - This function returns the peer's certificate status
   * @state: is a gnutls state
@@ -343,7 +351,11 @@ int _gnutls_openpgp_cert_verify_peers(GNUTLS_STATE state)
 	
 	/* Verify certificate 
 	 */
-	verify = gnutls_openpgp_verify_key( cred->pgp_trustdb, &cred->keyring, &info->raw_certificate_list[0],
+	if (_E_gnutls_openpgp_verify_key==NULL) {
+		gnutls_assert();
+		return GNUTLS_E_INVALID_REQUEST;
+	}
+	verify = _E_gnutls_openpgp_verify_key( cred->pgp_trustdb, &cred->keyring, &info->raw_certificate_list[0],
 				      peer_certificate_list_size);
 
 	if (verify < 0) {
@@ -425,7 +437,9 @@ time_t gnutls_certificate_expiration_time_peers(GNUTLS_STATE state)
 			return gnutls_x509_extract_certificate_expiration_time(
 				&info->raw_certificate_list[0]);
 		case GNUTLS_CRT_OPENPGP:
-			return gnutls_openpgp_extract_key_expiration_time(
+			if (_E_gnutls_openpgp_extract_key_expiration_time==NULL)
+				return (time_t)-1;
+			return _E_gnutls_openpgp_extract_key_expiration_time(
 				&info->raw_certificate_list[0]);
 		default:
 			return (time_t)-1;
@@ -464,7 +478,9 @@ time_t gnutls_certificate_activation_time_peers(GNUTLS_STATE state)
 			return gnutls_x509_extract_certificate_activation_time(
 				&info->raw_certificate_list[0]);
 		case GNUTLS_CRT_OPENPGP:
-			return gnutls_openpgp_extract_key_creation_time(
+			if (_E_gnutls_openpgp_extract_key_creation_time==NULL)
+				return (time_t)-1;
+			return _E_gnutls_openpgp_extract_key_creation_time(
 				&info->raw_certificate_list[0]);
 		default:
 			return (time_t)-1;
