@@ -1,7 +1,7 @@
-void WRITEdatum16( opaque* dest, gnutls_datum dat);
-void WRITEdatum24( opaque* dest, gnutls_datum dat);
-void WRITEdatum32( opaque* dest, gnutls_datum dat);
-void WRITEdatum8( opaque* dest, gnutls_datum dat);
+void _gnutls_write_datum16( opaque* dest, gnutls_datum dat);
+void _gnutls_write_datum24( opaque* dest, gnutls_datum dat);
+void _gnutls_write_datum32( opaque* dest, gnutls_datum dat);
+void _gnutls_write_datum8( opaque* dest, gnutls_datum dat);
 
 int gnutls_set_datum( gnutls_datum* dat, const void* data, int data_size);
 int gnutls_datum_append( gnutls_datum* dat, const void* data, int data_size);
