@@ -31,22 +31,22 @@
 #define byteswap16(x)  ((rotl16(x, 8) & 0x00ff) | (rotr16(x, 8) & 0xff00))
 #define byteswap32(x)  ((rotl32(x, 8) & 0x00ff00ffUL) | (rotr32(x, 8) & 0xff00ff00UL))
 
-uint32 uint24touint32( uint24 num);
-uint24 uint32touint24( uint32 num);
-uint32 READuint32( const opaque* data);
-uint16 READuint16( const opaque* data);
-uint32 CONVuint32( uint32 data);
-uint16 CONVuint16( uint16 data);
-uint64 CONVuint64( const uint64 *data);
-uint32 READuint24( const opaque* data);
-void WRITEuint24( uint32 num, opaque* data);
-void WRITEuint32( uint32 num, opaque* data);
-void WRITEuint16( uint16 num, opaque* data);
-uint32 uint64touint32( const uint64*);
+uint32 _gnutls_uint24touint32( uint24 num);
+uint24 _gnutls_uint32touint24( uint32 num);
+uint32 _gnutls_read_uint32( const opaque* data);
+uint16 _gnutls_read_uint16( const opaque* data);
+uint32 _gnutls_conv_uint32( uint32 data);
+uint16 _gnutls_conv_uint16( uint16 data);
+uint64 _gnutls_conv_uint64( const uint64 *data);
+uint32 _gnutls_read_uint24( const opaque* data);
+void _gnutls_write_uint24( uint32 num, opaque* data);
+void _gnutls_write_uint32( uint32 num, opaque* data);
+void _gnutls_write_uint16( uint16 num, opaque* data);
+uint32 _gnutls_uint64touint32( const uint64*);
 
 #ifndef HAVE_UINT64
-int uint64zero( uint64 *);
-int uint64pp( uint64 *);
+int _gnutls_uint64zero( uint64 *);
+int _gnutls_uint64pp( uint64 *);
 # define UINT64DATA(x) x.i
 
 #else
@@ -55,7 +55,7 @@ int uint64pp( uint64 *);
 # define rotr64(x,n)   (((x) >> ((uint16)(n))) | ((x) << (64 - (uint16)(n))))
 # define byteswap64(x)  ((rotl64(x, 8) & 0x00ff00ff00ff00ffUL) | (rotr64(x, 8) & 0xff00ff00ff00ff00UL))
 
-# define uint64pp(x) ((++(*x)==0) ? -1 : 0)
-# define uint64zero(x) (*x) = 0
+# define _gnutls_uint64pp(x) ((++(*x)==0) ? -1 : 0)
+# define _gnutls_uint64zero(x) (*x) = 0
 
 #endif
