@@ -3,19 +3,20 @@
  *
  * This file is part of GNUTLS.
  *
- * GNUTLS is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ *  The GNUTLS library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Lesser General Public   
+ *  License as published by the Free Software Foundation; either 
+ *  version 2.1 of the License, or (at your option) any later version.
  *
- * GNUTLS is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of 
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Lesser General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this library; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
  */
 
 #include <gnutls_int.h>
@@ -128,7 +129,6 @@ void _gnutls_handshake_internal_state_clear( GNUTLS_STATE state) {
 	state->gnutls_internals.adv_version_minor = 0;
 	state->gnutls_internals.adv_version_minor = 0;
 
-	state->gnutls_internals.resumed = RESUME_FALSE;
 	state->gnutls_internals.resumable = RESUME_TRUE;
 
 }
@@ -427,6 +427,31 @@ void gnutls_record_set_cbc_protection(GNUTLS_STATE state, int prot)
 	state->gnutls_internals.cbc_protection_hack = prot;
 }
 
+/**
+  * gnutls_handshake_set_rsa_pms_check - Used to disable the RSA PMS check
+  * @state: is a &GNUTLS_STATE structure.
+  * @prot: is an integer (0 or 1)
+  *
+  * The TLS 1.0 handshake protocol includes a check in the in the RSA
+  * encrypted data (only in the case of RSA key exchange), which allows
+  * to detect version roll back attacks. 
+  *
+  * However it seems that some broken TLS clients exist which do not
+  * use this check properly. The only solution is to disable this
+  * check completely.
+  *
+  * if check == 0 then the check is enabled (default), otherwise it
+  * is disabled.
+  *
+  * The protection used will slightly decrease performance, and add 
+  * 20 or more bytes per record packet.
+  *
+  **/
+void gnutls_handshake_set_rsa_pms_check(GNUTLS_STATE state, int check)
+{
+	state->gnutls_internals.rsa_pms_check = check;
+}
+
 inline
 static void _gnutls_cal_PRF_A( MACAlgorithm algorithm, void *secret, int secret_size, void *seed, int seed_size, void* result)
 {
@@ -572,3 +597,53 @@ int _gnutls_PRF( opaque * secret, int secret_size, uint8 * label, int label_size
 	return 0; /* ok */
 
 }
+
+/**
+  * gnutls_session_is_resumed - Used to check whether this session is a resumed one
+  * @state: is a &GNUTLS_STATE structure.
+  *
+  * This function will return non zero if this session is a resumed one,
+  * or a zero if this is a new session.
+  *
+  **/
+int gnutls_session_is_resumed(GNUTLS_STATE state)
+{
+	if (state->security_parameters.entity==GNUTLS_CLIENT) {
+		if (memcmp( state->security_parameters.session_id,
+			state->gnutls_internals.resumed_security_parameters.session_id,
+			state->security_parameters.session_id_size)==0)
+			return 1;
+	} else {
+		if (state->gnutls_internals.resumed==RESUME_TRUE)
+			return 1;
+	}
+
+	return 0;
+}
+
+/**
+  * gnutls_state_get_ptr - Used to get the user pointer from the state structure
+  * @state: is a &GNUTLS_STATE structure.
+  *
+  * This function will return the user given pointer from the state structure.
+  * This is the pointer set with gnutls_state_set_ptr().
+  *
+  **/
+void* gnutls_state_get_ptr(GNUTLS_STATE state)
+{
+	return state->gnutls_internals.user_ptr;
+}
+
+/**
+  * gnutls_state_set_ptr - Used to set the user pointer to the state structure
+  * @state: is a &GNUTLS_STATE structure.
+  * @ptr: is the user pointer
+  *
+  * This function will set (assosiate) the user given pointer to the state structure.
+  * This is pointer can be accessed with gnutls_state_get_ptr().
+  *
+  **/
+void gnutls_state_set_ptr(GNUTLS_STATE state, void* ptr)
+{
+	state->gnutls_internals.user_ptr = ptr;
+}
