@@ -36,12 +36,11 @@
  */
 
 
-int _gnutls_srp_gx(opaque * text, int textsize, opaque ** result, GNUTLS_MPI g,
+int _gnutls_srp_gx(opaque * text, size_t textsize, opaque ** result, GNUTLS_MPI g,
 		   GNUTLS_MPI prime)
 {
-
 	GNUTLS_MPI x, e;
-	int result_size;
+	size_t result_size;
 
 	if (_gnutls_mpi_scan(&x, text, &textsize)) {
 		gnutls_assert();
@@ -124,7 +123,7 @@ GNUTLS_MPI _gnutls_calc_srp_B(GNUTLS_MPI * ret_b, GNUTLS_MPI g, GNUTLS_MPI n, GN
 
 GNUTLS_MPI _gnutls_calc_srp_u(GNUTLS_MPI B)
 {
-	int b_size;
+	size_t b_size;
 	opaque *b_holder, hd[MAX_HASH_SIZE];
 	GNUTLS_HASH_HANDLE td;
 	uint32 u;
@@ -259,7 +258,7 @@ int _gnutls_calc_srp_sha(char *username, char *password, opaque * salt,
 }
 
 int _gnutls_calc_srp_x(char *username, char *password, opaque * salt,
-			 int salt_size, uint8 crypt_algo, int *size, void* digest)
+			 size_t salt_size, uint8 crypt_algo, size_t *size, void* digest)
 {
 
 	switch (crypt_algo) {
