@@ -22,12 +22,10 @@
 #include <string.h>
 #include <stdlib.h>
 #include <unistd.h>
-#include "../lib/defines.h"
-#include "../lib/gnutls_int.h"
-#include "../lib/gnutls_srp.h"
-#include "../lib/crypt.h"
-#include "../lib/x509_b64.h"
 #include "prime-gaa.h"
+#include <gcrypt.h>
+#include "../lib/gnutls.h"
+#include "../lib/defines.h"
 
 MPI _gcry_generate_elg_prime( int mode, unsigned pbits, unsigned qbits,
 	                MPI g, MPI **ret_factors );
@@ -44,7 +42,12 @@ int main(int argc, char **argv)
 		fprintf(stderr, "Error in the arguments.\n");
 		return -1;
 	}
+	
+	gnutls_global_init();
 
+	fprintf(stderr, "Generating prime...");
+	gcry_control (GCRYCTL_SET_VERBOSITY, (int)0);
+	
 	/* this is an emulation of Michael Wiener's table
 	 * bad emulation.
 	 */
@@ -93,5 +96,7 @@ int main(int argc, char **argv)
 	printf("\n};\n");
 	free(tmp);
 
+	gnutls_global_deinit();
+	
 	return 0;
 }
