@@ -28,6 +28,7 @@
 #include <string.h>
 #include <unistd.h>
 #include "../lib/gnutls.h"
+#include "../libextra/gnutls-extra.h"
 #include "common.h"
 #include <signal.h>
 #include "serv-gaa.h"
@@ -334,6 +335,11 @@ int main(int argc, char **argv)
       exit(1);
    }
 
+   if (gnutls_global_init_extra() < 0) {
+      fprintf(stderr, "global state initialization error\n");
+      exit(1);
+   }
+
    /* Note that servers must generate parameters for
     * Diffie Hellman. See gnutls_dh_params_generate(), and
     * gnutls_dh_params_set().
@@ -397,7 +403,13 @@ int main(int argc, char **argv)
     * Read README.crypt prior to using SRP.
     */
    gnutls_srp_allocate_server_sc(&srp_cred);
-   gnutls_srp_set_server_cred_file(srp_cred, srp_passwd, srp_passwd_conf);
+
+   if (srp_passwd!=NULL)
+   if ((ret=gnutls_srp_set_server_cred_file(srp_cred, srp_passwd, srp_passwd_conf)) < 0) {
+	/* only exit is this function is not disabled 
+	 */
+   	fprintf(stderr, "Error while setting SRP parameters\n");
+   }
 
    gnutls_anon_allocate_server_sc(&dh_cred);
    if (generate != 0)
@@ -446,6 +458,8 @@ int main(int argc, char **argv)
 	 continue;
       }
       printf("- Handshake was completed\n");
+      if ( gnutls_session_is_resumed( state)!=0)
+         printf("*** This is a resumed session\n");
 
       print_info(state);
 
